@@ -21,16 +21,19 @@ This module provides common methods for use across all service modules.
 import platform
 from iaesdk.version import __version__
 
-HEADER_NAME_USER_AGENT = 'User-Agent'
-SDK_NAME = 'ibm-iae-python-sdk'
+HEADER_NAME_USER_AGENT = "User-Agent"
+SDK_NAME = "ibm-iae-python-sdk"
+
 
 def get_system_info():
     """
     Get information about the system to be inserted into the User-Agent header
     """
-    return '{0} {1} {2}'.format(platform.system(), # OS
-                                platform.release(), # OS version
-                                platform.python_version()) # Python version
+    return "{0} {1} {2}".format(
+        platform.system(),  # OS
+        platform.release(),  # OS version
+        platform.python_version(),
+    )  # Python version
 
 
 def get_user_agent():
@@ -40,11 +43,11 @@ def get_user_agent():
     return USER_AGENT
 
 
-USER_AGENT = '{0}-{1} {2}'.format(SDK_NAME, __version__, get_system_info())
+USER_AGENT = "{0}-{1} {2}".format(SDK_NAME, __version__, get_system_info())
 
 
 def get_sdk_headers(service_name, service_version, operation_id):
-    #pylint: disable=unused-argument
+    # pylint: disable=unused-argument
     """
     Get the request headers to be sent in requests by the SDK
     """
